==> igniteui-angular-charts-18.0.0.tgz: package/esm5/lib/Stacked100BarSeries_combined.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { StackedBarSeries } from "./StackedBarSeries";
import { IStacked100Series_$type } from "./IStacked100Series";
import { Defaults } from "./Defaults";
import { markType } from "igniteui-angular-core";
import { Stacked100DataPreparer } from "./Stacked100DataPreparer";
import { isNaN_ } from "igniteui-angular-core";
import { StackedBarSeriesView } from "./StackedBarSeriesView";
import { Stacked100BarBucketCalculator } from "./Stacked100BarBucketCalculator";
/**
 * @hidden
 */
var Stacked100BarSeries = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(Stacked100BarSeries, _super);
    function Stacked100BarSeries() {
        var _this = _super.call(this) || this;
        _this.ab = Stacked100BarSeries.$;
        return _this;
    }
    Stacked100BarSeries.prototype.get_y4 = function () {
        return true;
    };
    Stacked100BarSeries.prototype.i0 = function () {
        if (!isNaN_(this.iz)) {
            return _super.prototype.i0.call(this);
        }
        return Defaults.h;
    };
    Stacked100BarSeries.prototype.ac = function () {
        _super.prototype.ac.call(this);
        this.qm(false);
    };
    Stacked100BarSeries.prototype.ci = function () {
        return new Stacked100BarSeriesView(this);
    };
    Stacked100BarSeries.prototype.px = function (a) {
        _super.prototype.px.call(this, a);
        this.z8 = a;
    };
    Stacked100BarSeries.prototype.yv = function () {
        return this.z8;
    };
    Stacked100BarSeries.prototype.zk = function () {
        _super.prototype.zk.call(this);
        Stacked100DataPreparer.a(this);
    };
    Object.defineProperty(Stacked100BarSeries.prototype, "useHighMarkerFidelity", {
        get: function () {
            return this.xy;
        },
        enumerable: false,
        configurable: true
    });
    Stacked100BarSeries.$t = markType(Stacked100BarSeries, 'Stacked100BarSeries', StackedBarSeries.$, [IStacked100Series_$type]);
    return Stacked100BarSeries;
}(StackedBarSeries));
export { Stacked100BarSeries };
/**
 * @hidden
 */
var Stacked100BarSeriesView = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(Stacked100BarSeriesView, _super);
    function Stacked100BarSeriesView(a) {
        var _this = _super.call(this, a) || this;
        _this.c9 = null;
        _this.c9 = a;
        return _this;
    }
    Stacked100BarSeriesView.prototype.cv = function () {
        return new Stacked100BarBucketCalculator(this);
    };
    Stacked100BarSeriesView.prototype.au = function () {
        _super.prototype.au.call(this);
        if (!this.q) {
            this.c3.vp = Defaults.c;
            this.c3.i5 = Defaults.i;
        }
    };
    Stacked100BarSeriesView.$t = markType(Stacked100BarSeriesView, 'Stacked100BarSeriesView', StackedBarSeriesView.$);
    return Stacked100BarSeriesView;
}(StackedBarSeriesView));
export { Stacked100BarSeriesView };

==> igniteui-angular-charts-18.1.0.tgz: package/esm5/lib/Stacked100BarSeries_combined.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { StackedBarSeries } from "./StackedBarSeries";
import { IStacked100Series_$type } from "./IStacked100Series";
import { Defaults } from "./Defaults";
import { markType } from "igniteui-angular-core";
import { Stacked100DataPreparer } from "./Stacked100DataPreparer";
import { isNaN_ } from "igniteui-angular-core";
import { StackedBarSeriesView } from "./StackedBarSeriesView";
import { Stacked100BarBucketCalculator } from "./Stacked100BarBucketCalculator";
/**
 * @hidden
 */
var Stacked100BarSeries = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(Stacked100BarSeries, _super);
    function Stacked100BarSeries() {
        var _this = _super.call(this) || this;
        _this.ab = Stacked100BarSeries.$;
        return _this;
    }
    Stacked100BarSeries.prototype.get_aam = function () {
        return true;
    };
    Stacked100BarSeries.prototype.ji = function () {
        if (!isNaN_(this.jh)) {
            return _super.prototype.ji.call(this);
        }
        return Defaults.h;
    };
    Stacked100BarSeries.prototype.ac = function () {
        _super.prototype.ac.call(this);
        this.rm(false);
    };
    Stacked100BarSeries.prototype.cq = function () {
        return new Stacked100BarSeriesView(this);
    };
    Stacked100BarSeries.prototype.qw = function (a) {
        _super.prototype.qw.call(this, a);
        this.abq = a;
    };
    Stacked100BarSeries.prototype.aad = function () {
        return this.abq;
    };
    Stacked100BarSeries.prototype.aa2 = function () {
        _super.prototype.aa2.call(this);
        Stacked100DataPreparer.a(this);
    };
    Object.defineProperty(Stacked100BarSeries.prototype, "useHighMarkerFidelity", {
        get: function () {
            return this.zg;
        },
        enumerable: false,
        configurable: true
    });
    Stacked100BarSeries.$t = markType(Stacked100BarSeries, 'Stacked100BarSeries', StackedBarSeries.$, [IStacked100Series_$type]);
    return Stacked100BarSeries;
}(StackedBarSeries));
export { Stacked100BarSeries };
/**
 * @hidden
 */
var Stacked100BarSeriesView = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(Stacked100BarSeriesView, _super);
    function Stacked100BarSeriesView(a) {
        var _this = _super.call(this, a) || this;
        _this.db = null;
        _this.db = a;
        return _this;
    }
    Stacked100BarSeriesView.prototype.cx = function () {
        return new Stacked100BarBucketCalculator(this);
    };
    Stacked100BarSeriesView.prototype.au = function () {
        _super.prototype.au.call(this);
        if (!this.q) {
            this.c5.w1 = Defaults.c;
            this.c5.jn = Defaults.i;
        }
    };
    Stacked100BarSeriesView.$t = markType(Stacked100BarSeriesView, 'Stacked100BarSeriesView', StackedBarSeriesView.$);
    return Stacked100BarSeriesView;
}(StackedBarSeriesView));
export { Stacked100BarSeriesView };
